@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -67,7 +67,8 @@ void adjust_marks_and_pointers( Buffer & b, const Point & p1,
       {
       if( *pv[i] < p2_old )			// was in the block, keep in
         {
-        if( *pv[i] >= p2_new ) { *pv[i] = p2_new; b.pprev( *pv[i] ); }
+        if( *pv[i] >= p2_new )
+          { *pv[i] = p2_new; if( *pv[i] > p1 ) b.pprev( *pv[i] ); }
         else if( !b.pisvalid( *pv[i] ) ) b.pvalid( *pv[i] );
         }
       else					// was beyond the block
@@ -176,7 +177,7 @@ bool Buffer::Options::set_rmargin( const int r )
   }
 
 
-Buffer::Buffer( const std::string * const namep )
+Buffer::Buffer( const std::string * const namep, const bool read_only )
   : backuped( false ), modified_( false ), saved( false ), crlf( false )
   {
   FILE * f = 0;
@@ -186,8 +187,8 @@ Buffer::Buffer( const std::string * const namep )
   else if( namep && namep->size() )
     {
     name_ = *namep;
-    f = std::fopen( name_.c_str(), "r+" );
-    if( !f && errno != ENOENT )
+    if( read_only ||
+        ( !(f = std::fopen( name_.c_str(), "r+" )) && errno != ENOENT ) )
       { f = std::fopen( name_.c_str(), "r" ); options.read_only = true; }
     }
   else return;
@@ -249,8 +250,8 @@ int Buffer::set_marks()
   }
 
 
-bool Buffer::save( const std::string * namep, bool set_name,
-                   bool append, Point p1, Point p2 ) const
+bool Buffer::save( const std::string * namep, const bool set_name,
+                   const bool append, Point p1, Point p2 ) const
   {
   int mode = 0;
   struct stat st;
