@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -211,10 +211,11 @@ public:
   Point mark[10];		// user bookmarks
   bool crlf;
 
-  explicit Buffer( const std::string * const namep = 0 );
+  explicit Buffer( const std::string * const namep = 0,
+                   const bool read_only = false );
   int set_marks();		// set initial user bookmarks
-  bool save( const std::string * namep = 0, bool set_name = true,
-             bool append = false, Point p1 = Point(), Point p2 = Point() ) const;
+  bool save( const std::string * namep = 0, const bool set_name = true,
+             const bool append = false, Point p1 = Point(), Point p2 = Point() ) const;
 
   long character_offset( const Point & p, int & percent ) const;
   bool modified() const { return modified_; }
