@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -158,14 +158,15 @@ void Bufhandle_vector::set_first( const int ai )
 
 
 int Bufhandle_vector::find_or_add_handle( const std::string * const namep,
-                                          int i, const int line, const int col )
+                                          int i, const int line, const int col,
+                                          const bool read_only )
   {
   if( namep && namep->size() )
     for( int j = 0; j < handles(); ++j )
       if( *namep == data[j].buffer().name() )
         return circular_index( j );
 
-  Buffer * bufp = new Buffer( namep );
+  Buffer * bufp = new Buffer( namep, read_only );
   RC::apply_all_file_options( *bufp );
 
   if( i < 0 ) i = handles();
