@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -55,7 +55,8 @@ void prev();
 void set_first( const int ai );
 
 int find_or_add_handle( const std::string * const namep = 0,
-                        int i = -1, const int line = 0, const int col = 0 );
+                        int i = -1, const int line = 0, const int col = 0,
+                        const bool read_only = false );
 void add_handle_if_pending_input_or_empty( const int line, const int col );
 void duplicate_handle( int i );
 bool delete_handle( int i );
