@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -110,6 +110,9 @@ int map_to_byte( const int code )
     case 0x00A8: return '"';	// diaeresis
     case 0x00B4: return '\'';	// acute accent
     case 0x00B8: return ',';	// cedilla
+    case 0x00BC:		// vulgar fraction one quarter
+    case 0x00BD:		// vulgar fraction one half
+    case 0x00BE: return -1;	// vulgar fraction three quarters
     case 0x0100: return 'A';	// latin capital letter a with macron
     case 0x0101: return 'a';	// latin small letter a with macron
     case 0x0102: return 'A';	// latin capital letter a with breve
@@ -983,6 +986,8 @@ int Encoding::utf8_decode( const std::string & in, std::string & out,
     const int ch = map_to_byte( code );
     if( ch >= 0 ) { if( ch < 256 ) { out += ch; } i += len; continue; }
     const char * const str = map_to_string( code );
+    if( str && code >= 0xBC && code <= 0xBE &&
+        !out.empty() && std::isdigit( out[out.size()-1] ) ) out += ' ';
     if( str ) out += str;
     else if( force ) out.append( in, i, len );
     else { if( idxp ) { *idxp = i; } return code; }
