@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ namespace {
 const char * const     Program_name = "GNU Moe";
 const char * const     program_name = "moe";
 const char * const config_file_name = "moerc";
-const char * const     program_year = "2015";
+const char * const     program_year = "2016";
 const char * invocation_name = 0;
 
 
@@ -65,7 +65,7 @@ void show_help()
                "  -V, --version            output version information and exit\n"
                "  -1, --orphan             put extra files in orphaned buffers\n"
                "  -b, --backup             create backup files (default)\n"
-               "  -B, --no-backup          do not create backup files\n"
+               "  -B, --no-backup          don't create backup files\n"
                "  -e, --exit-ask           make save-and-close ask always for confirmation\n"
                "  -H, --smart-home         go home, then go to first non-blank character\n"
                "  -i, --ignore-case        make search case insensitive by default\n"
@@ -162,7 +162,7 @@ bool use_it_anyway( const std::string & name )
 
 void process_config_file()
   {
-  std::fprintf( stderr, "\n" );
+  std::fputc( '\n', stderr );
   std::string name( RC::home_directory() );
   if( name.size() )
     {
@@ -189,7 +189,7 @@ const std::string & RC::home_directory()
   if( first_time )
     {
     first_time = false;
-    const char * p = std::getenv( "HOME" ); if( p ) home = p;
+    const char * const p = std::getenv( "HOME" ); if( p ) home = p;
     }
   return home;
   }
@@ -202,8 +202,8 @@ void RC::show_error( const char * const msg, const int errcode,
     {
     std::fprintf( stderr, "%s: %s", program_name, msg );
     if( errcode > 0 )
-      std::fprintf( stderr, ": %s.", std::strerror( errcode ) );
-    std::fprintf( stderr, "\n" );
+      std::fprintf( stderr, ": %s", std::strerror( errcode ) );
+    std::fputc( '\n', stderr );
     }
   if( help )
     std::fprintf( stderr, "Try '%s --help' for more information.\n",
@@ -229,7 +229,7 @@ int main( const int argc, const char * const argv[] )
   retval = RC::process_options();
   if( retval == 2 )
     {
-    std::fprintf( stderr, "Press RETURN to continue, Ctrl-C to abort.\n" );
+    std::fputs( "Press RETURN to continue, Ctrl-C to abort.\n", stderr );
     std::fgetc( stdin ); retval = 0;
     }
   if( retval ) return retval;
