@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ bool file_menu( const std::string & prompt, std::string & name );
 int get_filename( const std::string & prompt, std::string & name,
                   const int abort_key = 3 );
 
-bool is_regular( const std::string & name );
+bool is_regular( const std::string & name, bool * can_readp = 0 );
 
 bool make_path( const std::string & name );
 
