@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -336,13 +336,18 @@ int Menu::get_filename( const std::string & prompt, std::string & name,
   }
 
 
-bool Menu::is_regular( const std::string & name )
+bool Menu::is_regular( const std::string & name, bool * can_readp )
   {
   if( name.size() && name[name.size()-1] != '/' )
     {
     struct stat st;
     const int i = stat( name.c_str(), &st );
-    if( ( i == 0 && S_ISREG( st.st_mode ) ) ||
+    const mode_t mode = st.st_mode;
+    const bool can_read = ( i == 0 &&
+                            ( S_ISBLK( mode ) || S_ISCHR( mode ) ||
+                              S_ISFIFO( mode ) || S_ISSOCK( mode ) ) );
+    if( can_readp ) *can_readp = can_read;
+    if( ( i == 0 && S_ISREG( mode ) ) ||
         ( i == -1 && errno == ENOENT ) ) return true;
     }
   return false;
@@ -394,7 +399,7 @@ bool Menu::tilde_expansion( std::string & name )
 
 bool Menu::validate_filename( std::string & name )
   {
-  // do not deescapize filenames to avoid introducing control characters
+  // to avoid introducing control characters, don't deescapize filenames
   tilde_expansion( name );
   const std::string & basename = my_basename( name );
   return ( basename.size() && basename != "." && basename != ".." &&
