@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -221,10 +221,10 @@ bool set_option_from_code( const int code, const std::string & arg,
     }
 
   if( errcode == 1 )
-    std::fprintf( stderr, "%serror: Bad argument for option '%s'.\n",
+    std::fprintf( stderr, "%serror: Bad argument for option '%s'\n",
                   msg, optname( code ) );
   else if( errcode == 2 )
-    std::fprintf( stderr, "%serror: Value out of range for option '%s'.\n",
+    std::fprintf( stderr, "%serror: Value out of range for option '%s'\n",
                   msg, optname( code ) );
   return ( errcode == 0 );
   }
@@ -369,7 +369,7 @@ int RC::process_rcfile( const std::string & name )
         const int ch = std::fgetc( f );
         if( ch == EOF || ch == '\n' ) break;
         }
-      if( !retval ) std::fprintf( stderr, "\n" );
+      if( !retval ) std::fputc( '\n', stderr );
       std::fprintf( stderr, "%s %d: error: Line too long\n",
                     name.c_str(), line );
       retval = 2;
@@ -408,7 +408,7 @@ int RC::process_rcfile( const std::string & name )
       }
     }
   std::fclose( f );
-  if( !retval ) std::fprintf( stderr, "done\n" );
+  if( !retval ) std::fputs( "done\n", stderr );
   return retval;
   }
 
@@ -416,7 +416,7 @@ int RC::process_rcfile( const std::string & name )
     // Returns 0 if success, 1 if invalid option, 2 if a file can't be read.
 int RC::process_options()
   {
-  std::fprintf( stderr, "Processing options... " );
+  std::fputs( "Processing options... ", stderr );
   std::fflush( stderr );
 
   int argind = 0;
@@ -439,14 +439,14 @@ int RC::process_options()
       {
       if( !parse_line_col( parserp->argument( argind ), line, col ) )
         {
-        if( first_post ) std::fprintf( stderr, "\n" );
+        if( first_post ) std::fputc( '\n', stderr );
         show_error( "Bad number of line or column." );
         return 1;
         }
       if( ++argind >= parserp->arguments() ) break;
       if( parserp->code( argind ) )
         {
-        if( first_post ) std::fprintf( stderr, "\n" );
+        if( first_post ) std::fputc( '\n', stderr );
         show_error( "Options not allowed between line number and file name." );
         return 1;
         }
@@ -455,22 +455,24 @@ int RC::process_options()
     Buffer * bufferp = 0;
     std::string name( parserp->argument( argind++ ) );
     Menu::tilde_expansion( name );
-    if( Menu::is_regular( name ) )
+    bool can_read = false;
+    if( Menu::is_regular( name, &can_read ) || can_read )
       {
       try {
-        const int i = Bufhandle_vector::find_or_add_handle( &name, -1, line, col );
+        const int i = Bufhandle_vector::find_or_add_handle( &name, -1, line,
+                                                            col, can_read );
         bufferp = &Bufhandle_vector::handle( i ).buffer();
         }
       catch( Buffer::Error e )
         {
-        if( first_post ) { first_post = false; std::fprintf( stderr, "\n" ); }
+        if( first_post ) { first_post = false; std::fputc( '\n', stderr ); }
         std::fprintf( stderr, "warning: '%s': %s\n", name.c_str(), e.msg );
         read_error_found = true;
         }
       }
     else
       {
-      if( first_post ) { first_post = false; std::fprintf( stderr, "\n" ); }
+      if( first_post ) { first_post = false; std::fputc( '\n', stderr ); }
       std::fprintf( stderr, "warning: '%s' is not a regular file\n", name.c_str() );
       non_regular_found = true;
       }
@@ -490,19 +492,19 @@ int RC::process_options()
   try { Bufhandle_vector::add_handle_if_pending_input_or_empty( line, col ); }
   catch( Buffer::Error e )
     {
-    if( first_post ) std::fprintf( stderr, "\n" );
+    if( first_post ) std::fputc( '\n', stderr );
     show_error( e.msg );
     return 1;
     }
 
-  std::fprintf( stderr, "done\n" );
+  std::fputs( "done\n", stderr );
   delete parserp;
   if( non_regular_found || read_error_found )
     {
     if( non_regular_found )
-      std::fprintf( stderr, "warning: Non-regular files will be ignored.\n" );
+      std::fputs( "warning: Non-regular files will be ignored.\n", stderr );
     if( read_error_found )
-      std::fprintf( stderr, "warning: One or more files couldn't be read.\n" );
+      std::fputs( "warning: One or more files couldn't be read.\n", stderr );
     return 2;
     }
   return 0;
