@@ -1,5 +1,5 @@
 /*  GNU Moe - My Own Editor
-    Copyright (C) 2005-2015 Antonio Diaz Diaz.
+    Copyright (C) 2005-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -687,20 +687,25 @@ void Window_vector::center_line()
   const Point bot = buffer.bot( bol );
   const Point cbot = buffer.to_cursor( bot );
   const Point ceot = buffer.to_cursor( buffer.eot( bol ) );
-  const int l = cbot.col - buffer.options.lmargin();
-  const int r = buffer.options.rmargin() - ceot.col;
-  int dif = std::max( -bot.col, ( r - l ) / 2 );
+  int l = cbot.col - buffer.options.lmargin();
+  int r = buffer.options.rmargin() - ceot.col;
 
-  if( !read_only( buffer ) && cbot < ceot && dif )
+  if( !read_only( buffer ) && cbot < ceot && l != r && l != r + 1 )
     {
     buffer.reset_appendable();
-    if( dif > 0 || bot != cbot )
+    const int off = ( bot != cbot ) ? cbot.col : 0;
+    if( off )
+      { buffer.pdelb( bol, bot ); l -= off; r += off; buffer.force_append(); }
+    else if( l > r + 1 && bot.col > 0 )
+      buffer.pdelb( bol, Point( bot.line, std::min( bot.col, ( l - r ) / 2 ) ) );
+    if( l < r )
       {
-      if( bot != cbot )
-        { buffer.pdelb( bol, bot ); dif = ( l + r ) / 2; buffer.force_append(); }
-      Point p = bol; while( --dif >= 0 ) buffer.pputc( p, ' ' );
+      const bool ow = buffer.options.overwrite;
+      buffer.options.overwrite = false;
+      Point p = bol;
+      for( ; l < r; ++l, --r ) buffer.pputc( p, ' ' );
+      buffer.options.overwrite = ow;
       }
-    else buffer.pdelb( bol, Point( bot.line, -dif ) );
     buffer.reset_appendable();
     Screen::repaint( &buffer );
     }
